@@ -3,8 +3,8 @@
 import pandas as pd
 
 import statsmodels.tsa.api as tsa
-from models import ModelHub
-from links import Links  
+from pypungi.models import ModelHub
+from pypungi.links import Links  
 
 
 class hub():
